"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.floatFormatter = exports.integerFormatter = void 0;
const leftPadding = (size) => {
    return (input) => {
        if (input.length < size) {
            return " ".repeat(size - input.length) + input;
        }
        return input;
    };
};
exports.integerFormatter = (size) => {
    const padding = leftPadding(size);
    return (integer) => padding("" + integer);
};
exports.floatFormatter = (size, fractionDigits) => {
    const numberFormatter = new Intl.NumberFormat("en-US", {
        maximumFractionDigits: fractionDigits,
        minimumFractionDigits: fractionDigits,
        useGrouping: false
    });
    const padding = leftPadding(size);
    return (float) => padding(numberFormatter.format(float));
};
//# sourceMappingURL=formatters.js.map